Commit class

Represents a git commit item.

Constructors

Commit({required String id, required CommitAuthor author, required DateTime date, CommitMessage? message, String? type, String? description, CommitMessageHeader? header, bool? breaking, String? scope, String? body, List<CommitMessageFooter>? footer})
Create a Commit

Properties

author → CommitAuthor
The author of the commit
final
body → String
See CommitMessage.body
no setter
breaking → bool
See CommitMessage.breaking
no setter
date → DateTime
When the commit was made
final
description → String
See CommitMessage.description
no setter
See CommitMessage.footer
no setter
hashCode → int
The hash code for this object.
no setterinherited
See CommitMessage.header
no setter
id → String
Represents the commit ID.
final
isConventional → bool
See CommitMessage.isConventional
no setter
message → CommitMessage
The commit message
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
See CommitMessage.scope
no setter
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → String
See CommitMessage.type
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String logItem) → Commit
Parses a commit log item as returned from a git log item.
parseCommits(String logOutput) → List<Commit>
Creates a list of Commits from a git log output
parseCommitsStringList(List<String> strings) → List<Commit>
Creates a list of Commits from git log items as list